=== modified file 'bzrlib/osutils.py'
--- bzrlib/osutils.py	2006-12-26 15:29:50 +0000
+++ bzrlib/osutils.py	2007-01-02 16:04:11 +0000
@@ -1105,6 +1105,7 @@
                          '  doesn\'t support the locale set by $LANG (%s)\n'
                          "  Continuing with ascii encoding.\n"
                          % (e, os.environ.get('LANG')))
+        user_encoding = 'ascii'
 
     # Windows returns 'cp0' to indicate there is no code page. So we'll just
     # treat that as ASCII, and not support printing unicode characters to the

=== modified file 'bzrlib/tests/test_osutils_encodings.py'
--- bzrlib/tests/test_osutils_encodings.py	2007-01-02 14:32:36 +0000
+++ bzrlib/tests/test_osutils_encodings.py	2007-01-02 16:04:11 +0000
@@ -18,6 +18,7 @@
 
 import codecs
 import locale   # XXX: Do I need a woodoo for MacOS?
+import os
 import sys
 
 import bzrlib
@@ -154,10 +155,18 @@
         self._getpreferredencoding = locale.getpreferredencoding
         self.addCleanup(self._reset)
         sys.stderr = StringIOWrapper()
+        # save $LANG
+        self._LANG = os.environ.get('LANG')
 
     def _reset(self):
         locale.getpreferredencoding = self._getpreferredencoding
         sys.stderr = self._stderr
+        # restore $LANG
+        if self._LANG is not None:
+            os.environ['LANG'] = self._LANG
+        else:
+            if os.environ.get('LANG') is not None:
+                del os.environ['LANG']
 
     def test_get_user_encoding(self):
         def f():
@@ -185,3 +194,17 @@
         self.assertEquals('bzr: warning: unknown encoding cpUNKNOWN.'
                           ' Continuing with ascii encoding.\n',
                           sys.stderr.getvalue())
+
+    def test_user_locale_error(self):
+        def f():
+            raise locale.Error, 'unsupported locale'
+
+        locale.getpreferredencoding = f
+        os.environ['LANG'] = 'BOGUS'
+        self.assertEquals('ascii', osutils.get_user_encoding(use_cache=False))
+        self.assertEquals('bzr: warning: unsupported locale\n'
+                          '  Could not determine what text encoding to use.\n'
+                          '  This error usually means your Python interpreter\n'
+                          '  doesn\'t support the locale set by $LANG (BOGUS)\n'
+                          '  Continuing with ascii encoding.\n',
+                          sys.stderr.getvalue())

